@@ -2,7 +2,7 @@
 #ifndef _GLIBMM_CONTAINERHANDLE_SHARED_H
 #define _GLIBMM_CONTAINERHANDLE_SHARED_H
 
-/* $Id: containerhandle_shared.h 430 2007-08-03 23:07:43Z daniel $ */
+/* $Id: containerhandle_shared.h 681 2008-07-02 22:09:19Z jhs $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -54,11 +54,16 @@ namespace Glib
 /**
  * @ingroup ContHandles
  */
+ 
+//! Ownership of the container
+/*! Defines how and if the container will release the list and 
+ * its elemens when it is destroyed 
+ */
 enum OwnershipType
 {
-  OWNERSHIP_NONE = 0,
-  OWNERSHIP_SHALLOW, //Release the list, but not its elements, when the container is deleted
-  OWNERSHIP_DEEP //Release the list, and its elements, when the container is deleted.
+  OWNERSHIP_NONE = 0, /*!< Do not release anything */
+  OWNERSHIP_SHALLOW, /*!< Release the list, but not its elements, when the container is deleted */
+  OWNERSHIP_DEEP /*!< Release the list, and its elements, when the container is deleted. */
 };
 
 
